parsedatetime.tests

Package parsedatetime :: Package tests |
[hide private]
[frames] | no frames]

# Package tests

source code

Unit tests for parsedatetime

The tests can be run as a `suite` by running:

       python run_tests.py parsedatetime

Submodules | [hide private]
parsedatetime.tests.TestAustralianLocale: Test parsing of simple date and times using the Australian locale parsedatetime.tests.TestComplexDateTimes: Test parsing of complex date and times parsedatetime.tests.TestErrors: Test parsing of units parsedatetime.tests.TestInc: Test Calendar.Inc() routine parsedatetime.tests.TestMultiple: Test parsing of strings with multiple chunks parsedatetime.tests.TestPhrases: Test parsing of strings that are phrases parsedatetime.tests.TestRanges: Test parsing of simple date and times parsedatetime.tests.TestSimpleDateTimes: Test parsing of simple date and times parsedatetime.tests.TestSimpleOffsets: Test parsing of 'simple' offsets parsedatetime.tests.TestUnits: Test parsing of units

Variables | [hide private]
`` | license = `'\nCopyright (c) 2004-2007 Mike Taylor\nCopyright (c...`

Variables Details | [hide private]

    ### license None Value:
        '''
        Copyright (c) 2004-2007 Mike Taylor
        Copyright (c) 2006-2007 Darshana Chhajed
        All rights reserved.

        Licensed under the Apache License, Version 2.0 (the "License");
        you may not use this file except in compliance with the License.
        You may obtain a copy of the License at
        ...